Page Menu
Home
FreeBSD
Search
Configure Global Search
Log In
Files
F111103153
D14842.id48373.diff
No One
Temporary
Actions
View File
Edit File
Delete File
View Transforms
Subscribe
Mute Notifications
Flag For Later
Award Token
Size
49 KB
Referenced Files
None
Subscribers
None
D14842.id48373.diff
View Options
Index: multimedia/vlc/Makefile
===================================================================
--- multimedia/vlc/Makefile
+++ multimedia/vlc/Makefile
@@ -2,8 +2,7 @@
# $FreeBSD$
PORTNAME= vlc
-DISTVERSION= 2.2.8
-PORTREVISION= 11
+DISTVERSION= 3.0.4
PORTEPOCH= 4
CATEGORIES= multimedia audio ipv6 net www
MASTER_SITES= http://download.videolan.org/pub/videolan/${PORTNAME}/${DISTVERSION:S/a$//}/ \
@@ -19,19 +18,22 @@
libdvbpsi.so:multimedia/libdvbpsi \
libfontconfig.so:x11-fonts/fontconfig \
libfreetype.so:print/freetype2 \
- libidn.so:dns/libidn
+ libidn.so:dns/libidn \
+ libmatroska.so:multimedia/libmatroska
+
BUILD_DEPENDS= ffmpeg>=3.4.1,1:multimedia/ffmpeg \
yasm:devel/yasm
RUN_DEPENDS= ffmpeg>=3.4.1,1:multimedia/ffmpeg
+USES= compiler:c++11-lib desktop-file-utils gmake gnome iconv libtool \
+ pathfix pkgconfig tar:xz
+
# VLC git (post 2.2.4) requires C++11 support and passes the appropriate flag
# to the compiler. Until the port is updated, we explicitly pass -std=c++11 to
# the compiler because Qt 5.7+ requires C++11 support, and FreeBSD 10.3's clang
# does not default to C++11 mode.
USE_CXXSTD= c++11
-USES= compiler:c++11-lib desktop-file-utils gmake iconv libtool pathfix \
- pkgconfig tar:xz
USE_GNOME= libxml2
USE_LDCONFIG= yes
INSTALL_TARGET= install-strip
@@ -43,14 +45,14 @@
--enable-fontconfig --enable-freetype --enable-libgcrypt \
--enable-libxml2 --enable-oss --enable-postproc \
--enable-swscale --enable-vlc \
- --disable-alsa --disable-chromaprint --disable-crystalhd \
- --disable-dc1394 --disable-decklink --disable-directfb \
+ --disable-alsa --disable-archive --disable-chromaprint --disable-crystalhd \
+ --disable-dc1394 --disable-decklink --disable-dsm \
--disable-dv1394 --disable-fdkaac \
- --disable-gles1 --disable-gles2 --disable-kai --disable-kva \
+ --disable-gles2 --disable-kai --disable-kva \
--disable-vnc --disable-opencv --disable-projectm \
- --disable-telx \
+ --disable-secret --disable-soxr --disable-telx \
--disable-tiger --disable-tremor --disable-udev \
- --disable-update-check --disable-vcdx --disable-vsxu \
+ --disable-update-check --disable-vsxu \
--disable-wasapi --disable-x26410b \
--with-kde-solid=${PREFIX}/share/apps/solid/actions \
ac_cv_search_pthread_rwlock_init=-pthread
@@ -61,27 +63,29 @@
CFLAGS_i386= -fomit-frame-pointer
LIBS+= -L${LOCALBASE}/lib
-OPTIONS_DEFINE= A52 AALIB ASS AVAHI CACA DBUS DCA DOCS DVDREAD \
- DVDNAV FAAD FLAC FLUID FREERDP FRIBIDI GME GNOMEVFS2 GNUTLS \
- GOOM HTTPD JACK KATE LIBBLURAY LIBRSVG2 LIBSSH2 LIRC \
- LIVEMEDIA LUA MAD MATROSKA MODPLUG MPEG2 MTP MUSEPACK \
- NCURSES NLS NOTIFY OGG OPTIMIZED_CFLAGS OPUS PNG PULSEAUDIO \
+OPTIONS_DEFINE= A52 AALIB ASS AVAHI CACA CHROMECAST DBUS DCA DOCS DVDREAD \
+ DVDNAV FAAD FLAC FLUID FREERDP FRIBIDI GME GNUTLS \
+ GOOM HARFBUZZ JACK KATE LIBBLURAY LIBRSVG2 LIBSSH2 LIRC \
+ LIVEMEDIA LUA MAD MODPLUG MPEG2 MTP MUSEPACK \
+ NCURSES NFS NLS NOTIFY OGG OPTIMIZED_CFLAGS OPUS PNG PULSEAUDIO \
QT4 QT5 REALRTSP RUNROOT SAMPLERATE SIDPLAY SCHROEDINGER \
SDL SHOUTCAST SKINS SMB SNDIO STREAM SPEEX TAGLIB THEORA \
- TWOLAME UPNP V4L VAAPI VCD VDPAU VORBIS X11 X264 X265 ZVBI
+ TWOLAME UPNP V4L VAAPI VCD VDPAU VPX VORBIS WAYLAND X11 X264 X265 ZVBI
OPTIONS_DEFAULT=A52 AVAHI DBUS DCA DVDREAD DVDNAV FAAD FLAC GNUTLS \
- HTTPD LIVEMEDIA LUA MAD MATROSKA MPEG2 OGG OPTIMIZED_CFLAGS \
- OPUS PNG QT5 SAMPLERATE STREAM SPEEX TAGLIB THEORA TWOLAME V4L \
- VAAPI VCD VDPAU VORBIS X11
+ LIVEMEDIA LUA MAD MPEG2 OGG OPTIMIZED_CFLAGS \
+ OPUS PNG QT5 SAMPLERATE STREAM SPEEX TAGLIB THEORA TWOLAME \
+ V4L VAAPI VCD VDPAU VORBIS X11
OPTIONS_SUB= yes
ASS_DESC= ASS/SSA subtitle rendering
+CHROMECAST_DESC=Streaming to Chromecast devices
DVDREAD_DESC= DVD Playback support
DVDNAV_DESC= DVD menu navigation
FLUID_DESC= Fluidsynth MIDI support
FREERDP_DESC= RDP support
GME_DESC= Game Music Emu (libgme) support
GOOM_DESC= Goom visualisation plugin
+HARFBUZZ_DESC= OpenType text shaping engine
KATE_DESC= Kate codec support
LIBSSH2_DESC= SCP/SFTP support via libssh2
REALRTSP_DESC= Real RTSP access module
@@ -104,11 +108,14 @@
ASS_CONFIGURE_ENABLE= libass
AVAHI_LIB_DEPENDS= libavahi-common.so:net/avahi-app
-AVAHI_CONFIGURE_ENABLE= bonjour
+AVAHI_CONFIGURE_ENABLE= avahi
CACA_LIB_DEPENDS= libcaca.so:graphics/libcaca
CACA_CONFIGURE_ENABLE= caca
+CHROMECAST_LIB_DEPENDS= libprotobuf-lite.so:devel/protobuf
+CHROMECASE_CONFIGURE_ENABLE= chromecast
+
DBUS_LIB_DEPENDS= libdbus-1.so:devel/dbus
DBUS_CONFIGURE_ENABLE= dbus
@@ -145,16 +152,14 @@
GME_CONFIGURE_ENABLE= gme
GME_CONFIGURE_ENV= LIBS_gme="-L${LOCALBASE}/lib -lgme"
-GNOMEVFS2_USE= GNOME=gnomevfs2
-GNOMEVFS2_CONFIGURE_ENABLE= gnomevfs
-
GNUTLS_LIB_DEPENDS= libgnutls.so:security/gnutls
GNUTLS_CONFIGURE_ENABLE=gnutls
GOOM_LIB_DEPENDS= libgoom2.so:graphics/goom
GOOM_CONFIGURE_ENABLE= goom
-HTTPD_CONFIGURE_ENABLE= httpd
+HARFBUZZ_LIB_DEPENDS= libharfbuzz.so:print/harfbuzz
+HARFBUZZ_CONFIGURE_ENABLE= harfbuzz
JACK_LIB_DEPENDS= libjack.so:audio/jack
JACK_CONFIGURE_ENABLE= jack
@@ -195,9 +200,6 @@
MAD_CONFIGURE_ENABLE= mad
MAD_CONFIGURE_ON= --with-mad=${LOCALBASE}
-MATROSKA_LIB_DEPENDS= libmatroska.so:multimedia/libmatroska
-MATROSKA_CONFIGURE_ENABLE= mkv
-
MODPLUG_LIB_DEPENDS= libmodplug.so:audio/libmodplug
MODPLUG_CONFIGURE_ENABLE= mod
@@ -216,11 +218,14 @@
NCURSES_LIBS="-L${NCURSESLIB} -lncursesw"
NCURSES_CONFIGURE_ENABLE= ncurses
+NFS_LIB_DEPENDS= libnfs.so:net/libnfs
+NFS_CONFIGURE_ENABLE= nfs
+
NLS_USES= gettext
NLS_CONFIGURE_ENABLE= nls
NOTIFY_LIB_DEPENDS= libnotify.so:devel/libnotify
-NOTIFY_USE= GNOME=gtk20
+NOTIFY_USE= GNOME=gtk30
NOTIFY_CONFIGURE_ENABLE=notify
OGG_LIB_DEPENDS= libogg.so:audio/libogg
@@ -245,7 +250,7 @@
QT_LIBS="-lQtGui -L${QT_LIBDIR} -lQtCore"
QT5_USES= qt:5
-QT5_USE= QT=gui,core,widgets,x11extras,buildtools_build
+QT5_USE= QT=gui,core,svg,widgets,x11extras,buildtools_build
REALRTSP_CONFIGURE_ENABLE= realrtsp
@@ -258,7 +263,7 @@
SCHROEDINGER_CONFIGURE_ENABLE= schroedinger
SDL_USE= SDL=image
-SDL_CONFIGURE_ENABLE= sdl sdl-image
+SDL_CONFIGURE_ENABLE= sdl-image
SIDPLAY_LIB_DEPENDS= libsidplay2.so:audio/libsidplay2
SIDPLAY_LDFLAGS= -L${LOCALBASE}/lib/sidplay/builders
@@ -303,11 +308,20 @@
VDPAU_LIB_DEPENDS= libvdpau.so:multimedia/libvdpau
VDPAU_CONFIGURE_ENABLE= vdpau
+VDPAU_IMPLIES= X11
+
+VPX_LIB_DEPENDS= libvpx.so:multimedia/libvpx
+VPX_CONFIGURE_ENABLE= vpx
VORBIS_LIB_DEPENDS= libvorbis.so:audio/libvorbis
VORBIS_CONFIGURE_ENABLE=vorbis
+WAYLAND_BUILD_DEPENDS= wayland-protocols>=0:graphics/wayland-protocols
+WAYLAND_LIB_DEPENDS= libwayland-client.so:graphics/wayland
+WAYLAND_CONFIGURE_ENABLE= wayland
+
X11_USE= GL=gl XORG=xcb,xorgproto
+X11_USES= gl
X11_LIB_DEPENDS= libxcb-keysyms.so:x11/xcb-util-keysyms
X11_CONFIGURE_ENABLE= xcb xvideo
X11_CONFIGURE_WITH= x
Index: multimedia/vlc/distinfo
===================================================================
--- multimedia/vlc/distinfo
+++ multimedia/vlc/distinfo
@@ -1,3 +1,3 @@
-TIMESTAMP = 1514481430
-SHA256 (vlc-2.2.8.tar.xz) = 9bf046848fb56d93518881b39099b8288ee005d5ba0ddf705b6f6643b8d562ec
-SIZE (vlc-2.2.8.tar.xz) = 22137276
+TIMESTAMP = 1537685449
+SHA256 (vlc-3.0.4.tar.xz) = 01f3db3790714038c01f5e23c709e31ecd6f1c046ac93d19e1dde38b3fc05a9e
+SIZE (vlc-3.0.4.tar.xz) = 24934112
Index: multimedia/vlc/files/patch-clang
===================================================================
--- multimedia/vlc/files/patch-clang
+++ /dev/null
@@ -1,13 +0,0 @@
-Index: modules/demux/mkv/mkv.hpp
-===================================================================
---- modules/demux/mkv/mkv.hpp 2012-08-10 13:14:35.284287024 +0200
-+++ modules/demux/mkv/mkv.hpp 2012-08-10 13:15:13.839249260 +0200
-@@ -115,7 +115,7 @@
-
- #define MKVD_TIMECODESCALE 1000000
-
--#define MKV_IS_ID( el, C ) ( el != NULL && typeid( *el ) == typeid( C ) )
-+#define MKV_IS_ID( el, C ) ( EbmlId( (*el) ) == C::ClassInfos.GlobalId )
-
-
- using namespace LIBMATROSKA_NAMESPACE;
Index: multimedia/vlc/files/patch-configure
===================================================================
--- multimedia/vlc/files/patch-configure
+++ multimedia/vlc/files/patch-configure
@@ -1,57 +1,30 @@
---- configure.orig 2016-04-05 00:45:51 UTC
+--- configure.orig 2018-02-26 14:47:53 UTC
+++ configure
-@@ -8471,9 +8471,6 @@ case "${host_os}" in
+@@ -9027,9 +9027,6 @@ case "${host_os}" in
;;
freebsd*)
SYS=freebsd
- CFLAGS="${CFLAGS} -pthread"
- CPPFLAGS="${CPPFLAGS} -I/usr/local/include"
- LDFLAGS="${LDFLAGS} -L/usr/local/lib"
+ ac_cv_ld_z_defs=no
;;
openbsd*)
- SYS=openbsd
-@@ -25539,7 +25536,7 @@ main ()
- return 0;
- }
+@@ -25572,7 +25569,7 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
+ _Thread_local int foo = 0;
+ int main() {}
_ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"; then :
- ac_cv_c_o4=yes
-
-@@ -25583,7 +25580,7 @@ main ()
+ { $as_echo "$as_me:${as_lineno-$LINENO}: result: ok" >&5
+ $as_echo "ok" >&6; }
+@@ -27072,7 +27069,7 @@ main ()
return 0;
}
_ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"; then :
- ac_cv_c_o3=yes
-
-@@ -26777,7 +26774,7 @@ _ACEOF
- if ac_fn_c_try_compile "$LINENO"; then :
- ac_cv_altivec_inline="yes"
- else
-- CFLAGS="${CFLAGS} -Wa,-m7400"
-+ CFLAGS="${CFLAGS} -Wa,-maltivec"
- cat confdefs.h - <<_ACEOF >conftest.$ac_ext
- /* end confdefs.h. */
-
-@@ -26790,7 +26787,7 @@ asm volatile("vperm 0,1,2,3");
- }
- _ACEOF
- if ac_fn_c_try_compile "$LINENO"; then :
-- ac_cv_altivec_inline="-Wa,-m7400"
-+ ac_cv_altivec_inline="-Wa,-maltivec"
- else
- ac_cv_altivec_inline=no
- fi
-@@ -49199,7 +49196,7 @@ fi
- $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
- test $ac_status = 0; }; then
-
-- as_fn_error $? "\"You cannot build VLC with Qt-5.5.0. You need to backport I78ef29975181ee22429c9bd4b11d96d9e68b7a9c\"" "$LINENO" 5
-+ $as_echo "Qt-5.5.x found. Ensure Qt I78ef29975181ee22429c9bd4b11d96d9e68b7a9c is backported." >&5
-
- fi
+ ac_cv_c_visibility_hidden=yes
Index: multimedia/vlc/files/patch-ffmpeg30
===================================================================
--- multimedia/vlc/files/patch-ffmpeg30
+++ /dev/null
@@ -1,154 +0,0 @@
-Some changes are identical to upstream:
-https://git.videolan.org/?p=vlc.git;a=commitdiff;h=7db8b37716c0
-https://git.videolan.org/?p=vlc.git;a=commitdiff;h=d185cfaad535
-https://git.videolan.org/?p=vlc.git;a=commitdiff;h=5f91febe28de
-https://git.videolan.org/?p=vlc.git;a=commitdiff;h=3d2850fe7284
-https://git.videolan.org/?p=vlc.git;a=commitdiff;h=dbad0d2747e7
-
---- configure.orig 2016-05-31 16:56:33 UTC
-+++ configure
-@@ -36544,7 +36544,6 @@ $as_echo "yes" >&6; }
- :
- else
-
-- as_fn_error $? "libavutil versions 55 and later are not supported." "$LINENO" 5
-
- fi
-
-@@ -36836,7 +36835,6 @@ if test "${have_vaapi}" = "yes" -a "${ha
- $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
- test $ac_status = 0; }; then
-
-- as_fn_error $? "VA API requires FFmpeg libavcodec < 57.10 or libav." "$LINENO" 5
-
- fi
- ;;
-@@ -45112,7 +45110,6 @@ if test "${have_vdpau}" = "yes" -a "${ha
- $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
- test $ac_status = 0; }; then
-
-- as_fn_error $? "VDPAU requires FFmpeg libavcodec < 57.10 or libav." "$LINENO" 5
-
- fi
- ;;
---- modules/codec/avcodec/audio.c.orig 2016-01-18 20:49:57 UTC
-+++ modules/codec/avcodec/audio.c
-@@ -39,7 +39,7 @@
- #include <libavcodec/avcodec.h>
- #include <libavutil/mem.h>
-
--#include <libavutil/audioconvert.h>
-+#include <libavutil/channel_layout.h>
-
- #include "avcodec.h"
-
---- modules/codec/avcodec/avcommon_compat.h.orig 2015-02-02 19:42:29 UTC
-+++ modules/codec/avcodec/avcommon_compat.h
-@@ -506,6 +506,11 @@ enum {
-
- #endif /* HAVE_LIBAVUTIL_AVUTIL_H */
-
-+/* libavutil/pixfmt.h */
-+#ifndef PixelFormat
-+# define PixelFormat AVPixelFormat
-+#endif
-+
- #ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
- # include <libavformat/avformat.h>
-
---- modules/codec/avcodec/encoder.c.orig 2015-10-21 17:48:45 UTC
-+++ modules/codec/avcodec/encoder.c
-@@ -41,7 +41,7 @@
- #include <vlc_cpu.h>
-
- #include <libavcodec/avcodec.h>
--#include <libavutil/audioconvert.h>
-+#include <libavutil/channel_layout.h>
-
- #include "avcodec.h"
- #include "avcommon.h"
-@@ -311,7 +311,7 @@ int OpenEncoder( vlc_object_t *p_this )
- else if( !GetFfmpegCodec( p_enc->fmt_out.i_codec, &i_cat, &i_codec_id,
- &psz_namecodec ) )
- {
-- if( FindFfmpegChroma( p_enc->fmt_out.i_codec ) == PIX_FMT_NONE )
-+ if( FindFfmpegChroma( p_enc->fmt_out.i_codec ) == AV_PIX_FMT_NONE )
- return VLC_EGENERIC; /* handed chroma output */
-
- i_cat = VIDEO_ES;
-@@ -1017,7 +1017,7 @@ errmsg:
- }
- }
-
-- p_sys->frame = avcodec_alloc_frame();
-+ p_sys->frame = av_frame_alloc();
- if( !p_sys->frame )
- {
- goto error;
-@@ -1088,7 +1088,7 @@ static block_t *EncodeVideo( encoder_t *
- AVFrame *frame = NULL;
- if( likely(p_pict) ) {
- frame = p_sys->frame;
-- avcodec_get_frame_defaults( frame );
-+ av_frame_unref( frame );
- for( i_plane = 0; i_plane < p_pict->i_planes; i_plane++ )
- {
- p_sys->frame->data[i_plane] = p_pict->p[i_plane].p_pixels;
-@@ -1329,7 +1329,7 @@ static block_t *handle_delay_buffer( enc
- //How much we need to copy from new packet
- const int leftover = leftover_samples * p_sys->p_context->channels * p_sys->i_sample_bytes;
-
-- avcodec_get_frame_defaults( p_sys->frame );
-+ av_frame_unref( p_sys->frame );
- p_sys->frame->format = p_sys->p_context->sample_fmt;
- p_sys->frame->nb_samples = leftover_samples + p_sys->i_samples_delay;
-
-@@ -1451,7 +1451,7 @@ static block_t *EncodeAudio( encoder_t *
- while( ( p_aout_buf->i_nb_samples >= p_sys->i_frame_size ) ||
- ( p_sys->b_variable && p_aout_buf->i_nb_samples ) )
- {
-- avcodec_get_frame_defaults( p_sys->frame );
-+ av_frame_unref( p_sys->frame );
- if( p_sys->b_variable )
- p_sys->frame->nb_samples = p_aout_buf->i_nb_samples;
- else
---- modules/codec/avcodec/vaapi.c.orig 2015-02-02 19:42:29 UTC
-+++ modules/codec/avcodec/vaapi.c
-@@ -595,7 +595,7 @@ static int Create( vlc_va_t *p_va, AVCod
- return err;
-
- /* Only VLD supported */
-- p_va->pix_fmt = PIX_FMT_VAAPI_VLD;
-+ p_va->pix_fmt = AV_PIX_FMT_VAAPI_VLD;
- p_va->setup = Setup;
- p_va->get = Get;
- p_va->release = Release;
---- modules/codec/avcodec/video.c.orig 2016-04-07 19:36:15 UTC
-+++ modules/codec/avcodec/video.c
-@@ -234,7 +234,7 @@ int InitVideoDec( decoder_t *p_dec, AVCo
- p_sys->p_codec = p_codec;
- p_sys->i_codec_id = i_codec_id;
- p_sys->psz_namecodec = psz_namecodec;
-- p_sys->p_ff_pic = avcodec_alloc_frame();
-+ p_sys->p_ff_pic = av_frame_alloc();
- p_sys->b_delayed_open = true;
- p_sys->p_va = NULL;
- vlc_sem_init( &p_sys->sem_mt, 0 );
-@@ -446,7 +446,7 @@ int InitVideoDec( decoder_t *p_dec, AVCo
- if( ffmpeg_OpenCodec( p_dec ) < 0 )
- {
- msg_Err( p_dec, "cannot open codec (%s)", p_sys->psz_namecodec );
-- avcodec_free_frame( &p_sys->p_ff_pic );
-+ av_frame_free( &p_sys->p_ff_pic );
- vlc_sem_destroy( &p_sys->sem_mt );
- free( p_sys );
- return VLC_EGENERIC;
-@@ -826,7 +826,7 @@ void EndVideoDec( decoder_t *p_dec )
- wait_mt( p_sys );
-
- if( p_sys->p_ff_pic )
-- avcodec_free_frame( &p_sys->p_ff_pic );
-+ av_frame_free( &p_sys->p_ff_pic );
-
- if( p_sys->p_va )
- vlc_va_Delete( p_sys->p_va );
Index: multimedia/vlc/files/patch-ffmpeg40
===================================================================
--- multimedia/vlc/files/patch-ffmpeg40
+++ /dev/null
@@ -1,311 +0,0 @@
-https://git.videolan.org/?p=vlc.git;a=commitdiff;h=85b5b4e05f94
-https://git.videolan.org/?p=vlc.git;a=commitdiff;h=b337da993599
-https://git.videolan.org/?p=vlc.git;a=commitdiff;h=3546f6b0c024
-https://git.videolan.org/?p=vlc.git;a=commitdiff;h=84ce62d0a5a6
-
---- modules/codec/avcodec/avcommon_compat.h.orig 2015-03-01 14:07:35 UTC
-+++ modules/codec/avcodec/avcommon_compat.h
-@@ -479,6 +479,46 @@ enum {
- # define err_recognition error_recognition
- #endif
-
-+#ifndef AV_CODEC_FLAG_OUTPUT_CORRUPT
-+# define AV_CODEC_FLAG_OUTPUT_CORRUPT CODEC_FLAG_OUTPUT_CORRUPT
-+#endif
-+#ifndef AV_CODEC_FLAG_GRAY
-+# define AV_CODEC_FLAG_GRAY CODEC_FLAG_GRAY
-+#endif
-+#ifndef AV_CODEC_FLAG_DR1
-+# define AV_CODEC_FLAG_DR1 CODEC_FLAG_DR1
-+#endif
-+#ifndef AV_CODEC_FLAG_DELAY
-+# define AV_CODEC_FLAG_DELAY CODEC_FLAG_DELAY
-+#endif
-+#ifndef AV_CODEC_FLAG2_FAST
-+# define AV_CODEC_FLAG2_FAST CODEC_FLAG2_FAST
-+#endif
-+#ifndef FF_INPUT_BUFFER_PADDING_SIZE
-+# define FF_INPUT_BUFFER_PADDING_SIZE AV_INPUT_BUFFER_PADDING_SIZE
-+#endif
-+#ifndef AV_CODEC_FLAG_INTERLACED_DCT
-+# define AV_CODEC_FLAG_INTERLACED_DCT CODEC_FLAG_INTERLACED_DCT
-+#endif
-+#ifndef AV_CODEC_FLAG_INTERLACED_ME
-+# define AV_CODEC_FLAG_INTERLACED_ME CODEC_FLAG_INTERLACED_ME
-+#endif
-+#ifndef AV_CODEC_FLAG_GLOBAL_HEADER
-+# define AV_CODEC_FLAG_GLOBAL_HEADER CODEC_FLAG_GLOBAL_HEADER
-+#endif
-+#ifndef AV_CODEC_FLAG_LOW_DELAY
-+# define AV_CODEC_FLAG_LOW_DELAY CODEC_FLAG_LOW_DELAY
-+#endif
-+#ifndef AV_CODEC_CAP_SMALL_LAST_FRAME
-+# define AV_CODEC_CAP_SMALL_LAST_FRAME CODEC_CAP_SMALL_LAST_FRAME
-+#endif
-+#ifndef AV_INPUT_BUFFER_MIN_SIZE
-+# define AV_INPUT_BUFFER_MIN_SIZE FF_MIN_BUFFER_SIZE
-+#endif
-+#ifndef FF_MAX_B_FRAMES
-+# define FF_MAX_B_FRAMES 16 // FIXME: remove this
-+#endif
-+
- #endif /* HAVE_LIBAVCODEC_AVCODEC_H */
-
- #ifdef HAVE_LIBAVUTIL_AVUTIL_H
---- modules/codec/avcodec/encoder.c.orig 2015-10-21 16:36:45 UTC
-+++ modules/codec/avcodec/encoder.c
-@@ -285,6 +285,24 @@ static void probe_video_frame_rate( encoder_t *p_enc,
- msg_Dbg( p_enc, "Time base set to %d/%d", p_context->time_base.num, p_context->time_base.den );
- }
-
-+static void add_av_option_int( encoder_t *p_enc, AVDictionary** pp_dict, const char* psz_name, int i_value )
-+{
-+ char buff[32];
-+ if ( snprintf( buff, sizeof(buff), "%d", i_value ) < 0 )
-+ return;
-+ if( av_dict_set( pp_dict, psz_name, buff, 0 ) < 0 )
-+ msg_Warn( p_enc, "Failed to set encoder option %s", psz_name );
-+}
-+
-+static void add_av_option_float( encoder_t *p_enc, AVDictionary** pp_dict, const char* psz_name, float f_value )
-+{
-+ char buff[128];
-+ if ( snprintf( buff, sizeof(buff), "%f", f_value ) < 0 )
-+ return;
-+ if( av_dict_set( pp_dict, psz_name, buff, 0 ) < 0 )
-+ msg_Warn( p_enc, "Failed to set encoder option %s", psz_name );
-+}
-+
- int OpenEncoder( vlc_object_t *p_this )
- {
- encoder_t *p_enc = (encoder_t *)p_this;
-@@ -493,6 +511,7 @@ int OpenEncoder( vlc_object_t *p_this )
- }
- }
- free( psz_val );
-+ AVDictionary *options = NULL;
-
- if( p_enc->fmt_in.i_cat == VIDEO_ES )
- {
-@@ -522,7 +541,7 @@ int OpenEncoder( vlc_object_t *p_this )
- p_context->lumi_masking = p_sys->f_lumi_masking;
- p_context->dark_masking = p_sys->f_dark_masking;
- p_context->p_masking = p_sys->f_p_masking;
-- p_context->border_masking = p_sys->f_border_masking;
-+ add_av_option_float( p_enc, &options, "border_mask", p_sys->f_border_masking );
- #if (LIBAVCODEC_VERSION_MAJOR < 55)
- p_context->luma_elim_threshold = p_sys->i_luma_elim;
- p_context->chroma_elim_threshold = p_sys->i_chroma_elim;
-@@ -536,7 +555,7 @@ int OpenEncoder( vlc_object_t *p_this )
- if( !p_context->max_b_frames &&
- ( p_enc->fmt_out.i_codec == VLC_CODEC_MPGV ||
- p_enc->fmt_out.i_codec == VLC_CODEC_MP2V ) )
-- p_context->flags |= CODEC_FLAG_LOW_DELAY;
-+ p_context->flags |= AV_CODEC_FLAG_LOW_DELAY;
-
- av_reduce( &p_context->sample_aspect_ratio.num,
- &p_context->sample_aspect_ratio.den,
-@@ -594,16 +613,16 @@ int OpenEncoder( vlc_object_t *p_this )
- }
- else
- {
-- p_context->flags |= CODEC_FLAG_INTERLACED_DCT;
-+ p_context->flags |= AV_CODEC_FLAG_INTERLACED_DCT;
- if ( p_sys->b_interlace_me )
-- p_context->flags |= CODEC_FLAG_INTERLACED_ME;
-+ p_context->flags |= AV_CODEC_FLAG_INTERLACED_ME;
- }
- }
-
- p_context->trellis = p_sys->b_trellis;
-
- if ( p_sys->i_qmin > 0 && p_sys->i_qmin == p_sys->i_qmax )
-- p_context->flags |= CODEC_FLAG_QSCALE;
-+ p_context->flags |= AV_CODEC_FLAG_QSCALE;
- /* These codecs cause libavcodec to exit if thread_count is > 1.
- See libavcodec/mpegvideo_enc.c:MPV_encode_init and
- libavcodec/svq3.c , WMV2 calls MPV_encode_init also.
-@@ -639,12 +658,14 @@ int OpenEncoder( vlc_object_t *p_this )
- if( p_sys->i_qmin > 0 )
- {
- p_context->qmin = p_sys->i_qmin;
-- p_context->mb_lmin = p_context->lmin = p_sys->i_qmin * FF_QP2LAMBDA;
-+ p_context->mb_lmin = p_sys->i_qmin * FF_QP2LAMBDA;
-+ add_av_option_int( p_enc, &options, "lmin", p_context->mb_lmin);
- }
- if( p_sys->i_qmax > 0 )
- {
- p_context->qmax = p_sys->i_qmax;
-- p_context->mb_lmax = p_context->lmax = p_sys->i_qmax * FF_QP2LAMBDA;
-+ p_context->mb_lmax = p_sys->i_qmax * FF_QP2LAMBDA;
-+ add_av_option_int( p_enc, &options, "lmax", p_context->mb_lmax);
- }
- p_context->max_qdiff = 3;
-
-@@ -652,12 +673,12 @@ int OpenEncoder( vlc_object_t *p_this )
-
- if( p_sys->i_quality && !p_enc->fmt_out.i_bitrate )
- {
-- p_context->flags |= CODEC_FLAG_QSCALE;
-+ p_context->flags |= AV_CODEC_FLAG_QSCALE;
- p_context->global_quality = p_sys->i_quality;
- }
- else
- {
-- p_context->rc_qsquish = 1.0;
-+ av_dict_set(&options, "qsquish", "1.0", 0);
- /* Default to 1/2 second buffer for given bitrate unless defined otherwise*/
- if( !p_sys->i_rc_buffer_size )
- {
-@@ -671,7 +692,7 @@ int OpenEncoder( vlc_object_t *p_this )
- /* This is from ffmpeg's ffmpeg.c : */
- p_context->rc_initial_buffer_occupancy
- = p_sys->i_rc_buffer_size * 3/4;
-- p_context->rc_buffer_aggressivity = p_sys->f_rc_buffer_aggressivity;
-+ add_av_option_float( p_enc, &options, "rc_buffer_aggressivity", p_sys->f_rc_buffer_aggressivity );
- }
- }
- else if( p_enc->fmt_in.i_cat == AUDIO_ES )
-@@ -808,20 +829,23 @@ int OpenEncoder( vlc_object_t *p_this )
- if( !var_GetInteger( p_enc, ENC_CFG_PREFIX "qmin" ) )
- {
- p_context->qmin = 10;
-- p_context->mb_lmin = p_context->lmin = 10 * FF_QP2LAMBDA;
-+ p_context->mb_lmin = 10 * FF_QP2LAMBDA;
-+ add_av_option_int( p_enc, &options, "lmin", p_context->mb_lmin );
- }
-
- if( !var_GetInteger( p_enc, ENC_CFG_PREFIX "qmax" ) )
- {
- p_context->qmax = 42;
-- p_context->mb_lmax = p_context->lmax = 42 * FF_QP2LAMBDA;
-+ p_context->mb_lmax = 42 * FF_QP2LAMBDA;
-+ add_av_option_int( p_enc, &options, "lmax", p_context->mb_lmax );
- }
-
- } else {
- if( !var_GetInteger( p_enc, ENC_CFG_PREFIX "qmin" ) )
- {
- p_context->qmin = 1;
-- p_context->mb_lmin = p_context->lmin = FF_QP2LAMBDA;
-+ p_context->mb_lmin = FF_QP2LAMBDA;
-+ add_av_option_int( p_enc, &options, "lmin", p_context->mb_lmin );
- }
- }
-
-@@ -846,7 +870,7 @@ int OpenEncoder( vlc_object_t *p_this )
- /* Make sure we get extradata filled by the encoder */
- p_context->extradata_size = 0;
- p_context->extradata = NULL;
-- p_context->flags |= CODEC_FLAG_GLOBAL_HEADER;
-+ p_context->flags |= AV_CODEC_FLAG_GLOBAL_HEADER;
-
- if( p_enc->i_threads >= 1)
- p_context->thread_count = p_enc->i_threads;
-@@ -855,7 +879,6 @@ int OpenEncoder( vlc_object_t *p_this )
-
- int ret;
- char *psz_opts = var_InheritString(p_enc, ENC_CFG_PREFIX "options");
-- AVDictionary *options = NULL;
- if (psz_opts && *psz_opts)
- options = vlc_av_get_options(psz_opts);
- free(psz_opts);
-@@ -983,7 +1006,7 @@ errmsg:
- }
- }
-
-- p_context->flags &= ~CODEC_FLAG_GLOBAL_HEADER;
-+ p_context->flags &= ~AV_CODEC_FLAG_GLOBAL_HEADER;
-
- if( p_enc->fmt_in.i_cat == AUDIO_ES )
- {
-@@ -993,7 +1016,7 @@ errmsg:
- p_sys->i_sample_bytes = (p_enc->fmt_in.audio.i_bitspersample / 8);
- p_sys->i_frame_size = p_context->frame_size > 1 ?
- p_context->frame_size :
-- FF_MIN_BUFFER_SIZE;
-+ AV_INPUT_BUFFER_MIN_SIZE;
- p_sys->i_buffer_out = av_samples_get_buffer_size(NULL,
- p_sys->p_context->channels, p_sys->i_frame_size,
- p_sys->p_context->sample_fmt, DEFAULT_ALIGN);
-@@ -1359,7 +1382,7 @@ static block_t *handle_delay_buffer( encoder_t *p_enc,
- }
-
- if(unlikely( ( (leftover + buffer_delay) < p_sys->i_buffer_out ) &&
-- !(p_sys->p_codec->capabilities & CODEC_CAP_SMALL_LAST_FRAME )))
-+ !(p_sys->p_codec->capabilities & AV_CODEC_CAP_SMALL_LAST_FRAME )))
- {
- msg_Dbg( p_enc, "No small last frame support, padding");
- size_t padding_size = p_sys->i_buffer_out - (leftover+buffer_delay);
---- modules/codec/avcodec/video.c.orig 2017-07-13 09:16:59 UTC
-+++ modules/codec/avcodec/video.c
-@@ -251,11 +251,11 @@ int InitVideoDec( decoder_t *p_dec, AVCodecContext *p_
- var_InheritInteger( p_dec, "avcodec-error-resilience" );
-
- if( var_CreateGetBool( p_dec, "grayscale" ) )
-- p_sys->p_context->flags |= CODEC_FLAG_GRAY;
-+ p_sys->p_context->flags |= AV_CODEC_FLAG_GRAY;
-
- /* ***** Output always the frames ***** */
- #if LIBAVCODEC_VERSION_CHECK(55, 23, 1, 40, 101)
-- p_sys->p_context->flags |= CODEC_FLAG_OUTPUT_CORRUPT;
-+ p_sys->p_context->flags |= AV_CODEC_FLAG_OUTPUT_CORRUPT;
- #endif
-
- i_val = var_CreateGetInteger( p_dec, "avcodec-vismv" );
-@@ -268,7 +268,7 @@ int InitVideoDec( decoder_t *p_dec, AVCodecContext *p_
- else if( i_val == 1 ) p_sys->p_context->skip_loop_filter = AVDISCARD_NONREF;
-
- if( var_CreateGetBool( p_dec, "avcodec-fast" ) )
-- p_sys->p_context->flags2 |= CODEC_FLAG2_FAST;
-+ p_sys->p_context->flags2 |= AV_CODEC_FLAG2_FAST;
-
- /* ***** libavcodec frame skipping ***** */
- p_sys->b_hurry_up = var_CreateGetBool( p_dec, "avcodec-hurry-up" );
-@@ -295,7 +295,7 @@ int InitVideoDec( decoder_t *p_dec, AVCodecContext *p_
- p_sys->b_direct_rendering = false;
- p_sys->i_direct_rendering_used = -1;
- if( var_CreateGetBool( p_dec, "avcodec-dr" ) &&
-- (p_sys->p_codec->capabilities & CODEC_CAP_DR1) &&
-+ (p_sys->p_codec->capabilities & AV_CODEC_CAP_DR1) &&
- /* No idea why ... but this fixes flickering on some TSCC streams */
- p_sys->i_codec_id != AV_CODEC_ID_TSCC && p_sys->i_codec_id != AV_CODEC_ID_CSCD &&
- p_sys->i_codec_id != AV_CODEC_ID_CINEPAK &&
-@@ -308,16 +308,9 @@ int InitVideoDec( decoder_t *p_dec, AVCodecContext *p_
-
- /* libavcodec doesn't properly release old pictures when frames are skipped */
- //if( p_sys->b_hurry_up ) p_sys->b_direct_rendering = false;
-- if( p_sys->b_direct_rendering )
-- {
-- msg_Dbg( p_dec, "trying to use direct rendering" );
-- p_sys->p_context->flags |= CODEC_FLAG_EMU_EDGE;
-- }
-- else
-- {
-- msg_Dbg( p_dec, "direct rendering is disabled" );
-- }
--
-+#if !LIBAVCODEC_VERSION_CHECK(55, 32, 1, 48, 102)
-+ p_sys->p_context->flags |= CODEC_FLAG_EMU_EDGE;
-+#endif
- p_sys->p_context->get_format = ffmpeg_GetFormat;
- /* Always use our get_buffer wrapper so we can calculate the
- * PTS correctly */
-@@ -484,7 +477,7 @@ picture_t *DecodeVideo( decoder_t *p_dec, block_t **pp
- }
-
- p_block = *pp_block;
-- if(!p_block && !(p_sys->p_codec->capabilities & CODEC_CAP_DELAY) )
-+ if(!p_block && !(p_sys->p_codec->capabilities & AV_CODEC_CAP_DELAY) )
- return NULL;
-
- if( p_sys->b_delayed_open )
-@@ -621,7 +614,7 @@ picture_t *DecodeVideo( decoder_t *p_dec, block_t **pp
- }
- else
- {
-- /* Return delayed frames if codec has CODEC_CAP_DELAY */
-+ /* Return delayed frames if codec has AV_CODEC_CAP_DELAY */
- pkt.data = NULL;
- pkt.size = 0;
- }
Index: multimedia/vlc/files/patch-git_92ec47e
===================================================================
--- multimedia/vlc/files/patch-git_92ec47e
+++ /dev/null
@@ -1,43 +0,0 @@
-Partial import of upstream git-commit to fix build in c++11 mode
-
-From 92ec47e15b62ef12e15e6ce5550abe2620bc3167 Mon Sep 17 00:00:00 2001
-From: =?UTF-8?q?Hugo=20Beauz=C3=A9e-Luyssen?= <hugo@beauzee.fr>
-Date: Wed, 2 Jul 2014 14:17:19 +0000
-Subject: [PATCH] Fix build when using C++11
-
---- modules/access/live555.cpp.orig 2015-10-21 17:48:45 UTC
-+++ modules/access/live555.cpp
-@@ -307,7 +307,7 @@ static int Open ( vlc_object_t *p_this
- p_demux->p_sys = p_sys = (demux_sys_t*)calloc( 1, sizeof( demux_sys_t ) );
- if( !p_sys ) return VLC_ENOMEM;
-
-- msg_Dbg( p_demux, "version "LIVEMEDIA_LIBRARY_VERSION_STRING );
-+ msg_Dbg( p_demux, "version " LIVEMEDIA_LIBRARY_VERSION_STRING );
-
- TAB_INIT( p_sys->i_track, p_sys->track );
- p_sys->f_npt = 0.;
-@@ -593,7 +593,7 @@ createnew:
-
- p_sys->rtsp = new RTSPClientVlc( *p_sys->env, psz_url,
- var_InheritInteger( p_demux, "verbose" ) > 1 ? 1 : 0,
-- "LibVLC/"VERSION, i_http_port, p_sys );
-+ "LibVLC/" VERSION, i_http_port, p_sys );
- if( !p_sys->rtsp )
- {
- msg_Err( p_demux, "RTSPClient::createNew failed (%s)",
- modules/access/live555.cpp | 4 ++--
- modules/demux/mp4/libmp4.h | 2 +-
- modules/demux/vobsub.h | 8 +++----
- 10 files changed, 40 insertions(+), 40 deletions(-)
-
---- modules/demux/mp4/libmp4.h.orig 2015-02-02 19:42:29 UTC
-+++ modules/demux/mp4/libmp4.h
-@@ -1360,7 +1360,7 @@ static inline size_t mp4_box_headersize(
- if( i_actually_read < 0 || (int64_t)i_actually_read < i_read )\
- { \
- msg_Warn( p_stream, "MP4_READBOX_ENTER: I got %i bytes, "\
-- "but I requested %"PRId64"", i_actually_read, i_read );\
-+ "but I requested %" PRId64, i_actually_read, i_read );\
- free( p_buff ); \
- return( 0 ); \
- } \
Index: multimedia/vlc/files/patch-git_a1e5e64
===================================================================
--- multimedia/vlc/files/patch-git_a1e5e64
+++ /dev/null
@@ -1,27 +0,0 @@
-Only the skins2 bit is necessary, all other changes are already present in VLC
-2.2.4.
-
-From a1e5e6422d04cd3380bc5b10c86713fef0832aa3 Mon Sep 17 00:00:00 2001
-From: Tristan Matthews <le.businessman@gmail.com>
-Date: Wed, 2 Jul 2014 17:28:02 -0400
-Subject: [PATCH] Fix build for C++11
-
-C++11 requires a space between literal and identifier
----
- modules/gui/qt4/components/extended_panels.cpp | 4 ++--
- modules/gui/skins2/src/dialogs.cpp | 2 +-
- modules/video_filter/atmo/AtmoLiveView.cpp | 4 ++--
- modules/video_filter/atmo/atmo.cpp | 2 +-
- 4 files changed, 6 insertions(+), 6 deletions(-)
-
---- modules/gui/skins2/src/dialogs.cpp
-+++ modules/gui/skins2/src/dialogs.cpp
-@@ -212,7 +212,7 @@ void Dialogs::showChangeSkin()
- void Dialogs::showPlaylistLoad()
- {
- showFileGeneric( _("Open playlist"),
-- _("Playlist Files|"EXTENSIONS_PLAYLIST"|"
-+ _("Playlist Files|" EXTENSIONS_PLAYLIST "|"
- "All Files|*"),
- showPlaylistLoadCB, kOPEN );
- }
Index: multimedia/vlc/files/patch-git_a8953ba
===================================================================
--- multimedia/vlc/files/patch-git_a8953ba
+++ multimedia/vlc/files/patch-git_a8953ba
@@ -67,7 +67,7 @@
-#if X264_BUILD >= 111
add_integer( SOUT_CFG_PREFIX "frame-packing", -1, FRAMEPACKING_TEXT, FRAMEPACKING_LONGTEXT, true )
change_integer_list( framepacking_list, framepacking_list_text )
- change_integer_range( -1, 5)
+ change_integer_range( -1, 6)
-#endif
add_integer( SOUT_CFG_PREFIX "slices", 0, SLICE_COUNT, SLICE_COUNT_LONGTEXT, true )
@@ -84,7 +84,7 @@
/* Ratecontrol */
@@ -843,20 +822,14 @@ static int Open ( vlc_object_t *p_this )
- fullrange = var_GetBool( p_enc, SOUT_CFG_PREFIX "fullrange" );
+ fullrange |= p_enc->fmt_in.video.b_color_range_full;
p_enc->fmt_in.i_codec = fullrange ? VLC_CODEC_J420 : VLC_CODEC_I420;
p_sys->i_colorspace = X264_CSP_I420;
-#if X264_BUILD >= 118
@@ -97,7 +97,7 @@
# ifdef MODULE_NAME_IS_x26410b
- if( mask == 0)
- {
-- msg_Err( p_enc, "Only high bith depth encoding supported, bit depth:%d", x264_bit_depth);
+- msg_Err( p_enc, "Only high bit depth encoding supported, bit depth:%d", x264_bit_depth);
- return VLC_EGENERIC;
- }
+ const int mask = X264_CSP_HIGH_DEPTH;
@@ -106,7 +106,7 @@
# endif
+ if( psz_profile )
+ {
-
+
if( !strcmp( psz_profile, "high10" ) )
{
@@ -879,7 +852,6 @@ static int Open ( vlc_object_t *p_this )
Index: multimedia/vlc/files/patch-git_d2571e6
===================================================================
--- multimedia/vlc/files/patch-git_d2571e6
+++ /dev/null
@@ -1,51 +0,0 @@
-commit d2571e643edb0f1cb217805ef8d5ac172d59a864
-Author: Rémi Denis-Courmont <remi@remlab.net>
-Date: Fri Jun 26 00:06:44 2015 +0300
-
- qt: use QAtomicInt
-
-diff --git a/modules/gui/qt4/dialogs/messages.cpp b/modules/gui/qt4/dialogs/messages.cpp
-index 21c11107c7..d23007f036 100644
---- modules/gui/qt4/dialogs/messages.cpp
-+++ modules/gui/qt4/dialogs/messages.cpp
-@@ -146,7 +146,7 @@ MessagesDialog::~MessagesDialog()
-
- void MessagesDialog::changeVerbosity( int i_verbosity )
- {
-- atomic_store( &this->verbosity, i_verbosity );
-+ verbosity = i_verbosity;
- }
-
- void MessagesDialog::updateConfig()
-@@ -340,7 +340,7 @@ void MessagesDialog::MsgCallback( void *self, int type, const vlc_log_t *item,
- {
- MessagesDialog *dialog = (MessagesDialog *)self;
- char *str;
-- int verbosity = atomic_load( &dialog->verbosity );
-+ int verbosity = dialog->verbosity;
-
- if( verbosity < 0 || verbosity < (type - VLC_MSG_ERR)
- || unlikely(vasprintf( &str, format, ap ) == -1) )
-diff --git a/modules/gui/qt4/dialogs/messages.hpp b/modules/gui/qt4/dialogs/messages.hpp
-index a8d5804be2..0491a8f158 100644
---- modules/gui/qt4/dialogs/messages.hpp
-+++ modules/gui/qt4/dialogs/messages.hpp
-@@ -28,8 +28,8 @@
- #include "util/singleton.hpp"
- #include "ui/messages_panel.h"
- #include <stdarg.h>
--#include <vlc_atomic.h>
- #include <QMutex>
-+#include <QAtomicInt>
-
- class QPushButton;
- class QTreeWidget;
-@@ -49,7 +49,7 @@ private:
- void sinkMessage( const MsgEvent * );
- bool matchFilter( const QString& );
-
-- atomic_uint verbosity;
-+ QAtomicInt verbosity;
- static void MsgCallback( void *, int, const vlc_log_t *, const char *,
- va_list );
-
Index: multimedia/vlc/files/patch-include-vlc_common.h
===================================================================
--- multimedia/vlc/files/patch-include-vlc_common.h
+++ /dev/null
@@ -1,11 +0,0 @@
---- include/vlc_common.h.orig
-+++ include/vlc_common.h
-@@ -642,7 +642,7 @@ static inline unsigned popcount (unsigne
- #endif
- }
-
--#ifdef __OS2__
-+#if defined(__OS2__) || defined(__FreeBSD__)
- # undef bswap16
- # undef bswap32
- # undef bswap64
Index: multimedia/vlc/files/patch-include-vlc_threads.h
===================================================================
--- multimedia/vlc/files/patch-include-vlc_threads.h
+++ /dev/null
@@ -1,18 +0,0 @@
---- include/vlc_threads.h.orig 2013-10-22 15:47:18.000000000 +0200
-+++ include/vlc_threads.h 2013-10-22 15:48:00.000000000 +0200
-@@ -342,13 +342,13 @@
- * Removes a cleanup procedure that was previously registered with
- * vlc_cleanup_push().
- */
--# define vlc_cleanup_pop( ) pthread_cleanup_pop (0)
-+# define vlc_cleanup_pop( ) ; pthread_cleanup_pop (0)
-
- /**
- * Removes a cleanup procedure that was previously registered with
- * vlc_cleanup_push(), and executes it.
- */
--# define vlc_cleanup_run( ) pthread_cleanup_pop (1)
-+# define vlc_cleanup_run( ) ; pthread_cleanup_pop (1)
-
- #else
- enum
Index: multimedia/vlc/files/patch-include_vlc__atomic.h
===================================================================
--- multimedia/vlc/files/patch-include_vlc__atomic.h
+++ /dev/null
@@ -1,103 +0,0 @@
-Move vlc_atomic.h closer to the git version (post-2.2.4), especially revision
-ab550d60dd8d8 ("include: stick to a single version (2011) C/C++ atomics") by
-assuming C++ builds are being done in C++11 mode or later and include <atomic>.
-For C usages, use <stdatomic.h> in C11 mode and define some shims otherwise.
-
-The original 2.2.4 version does not have C++11 support and breaks with Qt5, as
-Qt 5.7+ requires C++11 support.
---- include/vlc_atomic.h.orig 2014-08-14 07:20:03 UTC
-+++ include/vlc_atomic.h
-@@ -26,13 +26,13 @@
- * Atomic operations do not require locking, but they are not very powerful.
- */
-
--# if !defined (__cplusplus) && (__STDC_VERSION__ >= 201112L) \
-- && !defined (__STDC_NO_ATOMICS__)
-+# ifndef __cplusplus
-+# if (__STDC_VERSION__ >= 201112L) && !defined (__STDC_NO_ATOMICS__)
-
- /*** Native C11 atomics ***/
- # include <stdatomic.h>
-
--# else
-+# else
-
- # define ATOMIC_FLAG_INIT false
-
-@@ -57,7 +57,7 @@
- * unsigned equivalents, i.e. 4-bytes and 8-bytes types, although GCC also
- * supports 1 and 2-bytes types. Some non-x86 architectures do not support
- * 8-byte atomic types (or not efficiently). */
--# if defined (_MSC_VER)
-+# if defined (_MSC_VER)
- /* Some atomic operations of the Interlocked API are only
- available for desktop apps. Thus we define the atomic types to
- be at least 32 bits wide. */
-@@ -68,7 +68,7 @@
- typedef uint_least32_t atomic_uchar;
- typedef int_least32_t atomic_short;
- typedef uint_least32_t atomic_ushort;
--# else
-+# else
- typedef bool atomic_flag;
- typedef bool atomic_bool;
- typedef char atomic_char;
-@@ -76,7 +76,7 @@
- typedef unsigned char atomic_uchar;
- typedef short atomic_short;
- typedef unsigned short atomic_ushort;
--# endif
-+# endif
- typedef int atomic_int;
- typedef unsigned int atomic_uint;
- typedef long atomic_long;
-@@ -109,7 +109,7 @@
- typedef intmax_t atomic_intmax_t;
- typedef uintmax_t atomic_uintmax_t;
-
--# if defined (__GCC_HAVE_SYNC_COMPARE_AND_SWAP_4) || (defined (__clang__) && (defined (__x86_64__) || defined (__i386__)))
-+# if defined (__GCC_HAVE_SYNC_COMPARE_AND_SWAP_4) || (defined (__clang__) && (defined (__x86_64__) || defined (__i386__)))
-
- /*** Intel/GCC atomics ***/
-
-@@ -203,7 +203,7 @@
- # define atomic_flag_clear_explicit(object,order) \
- atomic_flag_clear(object)
-
--# elif defined (__GNUC__)
-+# elif defined (__GNUC__)
-
- /*** No atomics ***/
-
-@@ -315,7 +315,7 @@
- # define atomic_flag_clear_explicit(object,order) \
- atomic_flag_clear(object)
-
--# elif defined (_MSC_VER)
-+# elif defined (_MSC_VER)
-
- # include <windows.h>
-
-@@ -397,10 +397,8 @@
- # define atomic_flag_clear_explicit(object,order) \
- atomic_flag_clear(object)
-
--# else
--# error FIXME: implement atomic operations for this compiler.
--# endif
--# endif
-+# endif
-+# endif
-
- typedef atomic_uint_least32_t vlc_atomic_float;
-
-@@ -427,4 +425,9 @@
- atomic_store(atom, u.i);
- }
-
-+# else /* C++ */
-+/*** Native C++11 atomics ***/
-+# include <atomic>
-+# endif
-+
- #endif
Index: multimedia/vlc/files/patch-include_vlc__playlist.h
===================================================================
--- multimedia/vlc/files/patch-include_vlc__playlist.h
+++ /dev/null
@@ -1,19 +0,0 @@
---- include/vlc_playlist.h.orig 2014-11-16 18:57:58 UTC
-+++ include/vlc_playlist.h
-@@ -24,13 +24,13 @@
- #ifndef VLC_PLAYLIST_H_
- #define VLC_PLAYLIST_H_
-
-+#include <vlc_input.h>
-+#include <vlc_events.h>
-+
- # ifdef __cplusplus
- extern "C" {
- # endif
-
--#include <vlc_input.h>
--#include <vlc_events.h>
--
- TYPEDEF_ARRAY(playlist_item_t*, playlist_item_array_t)
-
- struct intf_thread_t;
Index: multimedia/vlc/files/patch-include_vlc__sout.h
===================================================================
--- multimedia/vlc/files/patch-include_vlc__sout.h
+++ /dev/null
@@ -1,22 +0,0 @@
---- include/vlc_sout.h.orig 2014-11-16 18:57:58 UTC
-+++ include/vlc_sout.h
-@@ -28,6 +28,9 @@
- #ifndef VLC_SOUT_H_
- #define VLC_SOUT_H_
-
-+#include <sys/types.h>
-+#include <vlc_es.h>
-+
- /**
- * \file
- * This file defines structures and functions for stream output in vlc
-@@ -37,9 +40,6 @@
- extern "C" {
- #endif
-
--#include <sys/types.h>
--#include <vlc_es.h>
--
- /** Stream output instance (FIXME: should be private to src/ to avoid
- * invalid unsynchronized access) */
- struct sout_instance_t
Index: multimedia/vlc/files/patch-modules_gui_qt4_actions__manager.hpp
===================================================================
--- multimedia/vlc/files/patch-modules_gui_qt4_actions__manager.hpp
+++ /dev/null
@@ -1,12 +0,0 @@
-Fix build with Qt 5.11
-
---- modules/gui/qt4/actions_manager.hpp.orig 2018-09-03 09:20:39 UTC
-+++ modules/gui/qt4/actions_manager.hpp
-@@ -31,6 +31,7 @@
- #include "qt4.hpp"
- #include "util/singleton.hpp"
-
-+#include <QAction>
- #include <QObject>
- class QAction;
-
Index: multimedia/vlc/files/patch-modules_gui_qt4_components_simple__preferences.cpp
===================================================================
--- multimedia/vlc/files/patch-modules_gui_qt4_components_simple__preferences.cpp
+++ /dev/null
@@ -1,12 +0,0 @@
-Fix build with Qt 5.11
-
---- modules/gui/qt4/components/simple_preferences.cpp.orig 2018-09-03 09:38:13 UTC
-+++ modules/gui/qt4/components/simple_preferences.cpp
-@@ -36,6 +36,7 @@
- #include <QString>
- #include <QFont>
- #include <QToolButton>
-+#include <QButtonGroup>
- #include <QSignalMapper>
- #include <QVBoxLayout>
- #include <QScrollArea>
Index: multimedia/vlc/files/patch-v4l
===================================================================
--- multimedia/vlc/files/patch-v4l
+++ /dev/null
@@ -1,15 +0,0 @@
---- modules/access/v4l2/v4l2.h.orig 2013-10-22 10:17:30.534986266 -0200
-+++ modules/access/v4l2/v4l2.h 2013-10-22 10:17:39.613985219 -0200
-@@ -20,6 +20,12 @@
-
- #include <linux/videodev2.h>
-
-+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
-+#define V4L2_BUF_FLAG_TIMESTAMP_MASK 0xe000
-+#define V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN 0x0000
-+#define V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC 0x2000
-+#endif
-+
- /* libv4l2 functions */
- extern int v4l2_fd_open (int, int);
- extern int (*v4l2_close) (int);
Index: multimedia/vlc/pkg-plist
===================================================================
--- multimedia/vlc/pkg-plist
+++ multimedia/vlc/pkg-plist
@@ -8,6 +8,7 @@
bin/vlc-wrapper
include/vlc/deprecated.h
include/vlc/libvlc.h
+include/vlc/libvlc_dialog.h
include/vlc/libvlc_events.h
include/vlc/libvlc_media.h
include/vlc/libvlc_media_discoverer.h
@@ -15,11 +16,12 @@
include/vlc/libvlc_media_list.h
include/vlc/libvlc_media_list_player.h
include/vlc/libvlc_media_player.h
-include/vlc/libvlc_structures.h
+include/vlc/libvlc_renderer_discoverer.h
include/vlc/libvlc_version.h
include/vlc/libvlc_vlm.h
include/vlc/plugins/vlc_about.h
include/vlc/plugins/vlc_access.h
+include/vlc/plugins/vlc_actions.h
include/vlc/plugins/vlc_addons.h
include/vlc/plugins/vlc_aout.h
include/vlc/plugins/vlc_aout_volume.h
@@ -29,6 +31,7 @@
include/vlc/plugins/vlc_bits.h
include/vlc/plugins/vlc_block.h
include/vlc/plugins/vlc_block_helper.h
+include/vlc/plugins/vlc_boxes.h
include/vlc/plugins/vlc_charset.h
include/vlc/plugins/vlc_codec.h
include/vlc/plugins/vlc_common.h
@@ -53,13 +56,16 @@
include/vlc/plugins/vlc_inhibit.h
include/vlc/plugins/vlc_input.h
include/vlc/plugins/vlc_input_item.h
-include/vlc/plugins/vlc_keys.h
+include/vlc/plugins/vlc_interface.h
+include/vlc/plugins/vlc_interrupt.h
+include/vlc/plugins/vlc_keystore.h
include/vlc/plugins/vlc_main.h
include/vlc/plugins/vlc_md5.h
-include/vlc/plugins/vlc_meta_fetcher.h
include/vlc/plugins/vlc_media_library.h
+include/vlc/plugins/vlc_memstream.h
include/vlc/plugins/vlc_messages.h
include/vlc/plugins/vlc_meta.h
+include/vlc/plugins/vlc_meta_fetcher.h
include/vlc/plugins/vlc_mime.h
include/vlc/plugins/vlc_modules.h
include/vlc/plugins/vlc_mouse.h
@@ -74,18 +80,22 @@
include/vlc/plugins/vlc_plugin.h
include/vlc/plugins/vlc_probe.h
include/vlc/plugins/vlc_rand.h
+include/vlc/plugins/vlc_renderer_discovery.h
include/vlc/plugins/vlc_services_discovery.h
include/vlc/plugins/vlc_sout.h
include/vlc/plugins/vlc_spu.h
include/vlc/plugins/vlc_stream.h
+include/vlc/plugins/vlc_stream_extractor.h
include/vlc/plugins/vlc_strings.h
include/vlc/plugins/vlc_subpicture.h
include/vlc/plugins/vlc_text_style.h
include/vlc/plugins/vlc_threads.h
+include/vlc/plugins/vlc_timestamp_helper.h
include/vlc/plugins/vlc_tls.h
include/vlc/plugins/vlc_url.h
include/vlc/plugins/vlc_variables.h
include/vlc/plugins/vlc_video_splitter.h
+include/vlc/plugins/vlc_viewpoint.h
include/vlc/plugins/vlc_vlm.h
include/vlc/plugins/vlc_vout.h
include/vlc/plugins/vlc_vout_display.h
@@ -96,15 +106,16 @@
include/vlc/vlc.h
lib/libvlc.so
lib/libvlc.so.5
-lib/libvlc.so.5.5.1
+lib/libvlc.so.5.6.0
lib/libvlccore.so
-lib/libvlccore.so.8
-lib/libvlccore.so.8.0.1
+lib/libvlccore.so.9
+lib/libvlccore.so.9.0.0
libdata/pkgconfig/libvlc.pc
libdata/pkgconfig/vlc-plugin.pc
man/man1/vlc-wrapper.1.gz
man/man1/vlc.1.gz
share/applications/vlc.desktop
+share/icons/hicolor/128x128/apps/vlc-kb.png
share/icons/hicolor/128x128/apps/vlc-xmas.png
share/icons/hicolor/128x128/apps/vlc.png
share/icons/hicolor/16x16/apps/vlc.png
@@ -124,6 +135,7 @@
%%NLS%%share/locale/am/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/an/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/ar/LC_MESSAGES/vlc.mo
+%%NLS%%share/locale/as_IN/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/ast/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/az/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/be/LC_MESSAGES/vlc.mo
@@ -131,6 +143,7 @@
%%NLS%%share/locale/bn/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/bn_IN/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/br/LC_MESSAGES/vlc.mo
+%%NLS%%share/locale/brx/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/bs/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/ca/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/cgg/LC_MESSAGES/vlc.mo
@@ -143,7 +156,6 @@
%%NLS%%share/locale/el/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/en_GB/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/es/LC_MESSAGES/vlc.mo
-%%NLS%%share/locale/es_MX/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/et/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/eu/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/fa/LC_MESSAGES/vlc.mo
@@ -151,6 +163,7 @@
%%NLS%%share/locale/fi/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/fr/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/fur/LC_MESSAGES/vlc.mo
+%%NLS%%share/locale/fy/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/ga/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/gd/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/gl/LC_MESSAGES/vlc.mo
@@ -207,6 +220,7 @@
%%NLS%%share/locale/th/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/tl/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/tr/LC_MESSAGES/vlc.mo
+%%NLS%%share/locale/ug/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/uk/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/uz/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/vi/LC_MESSAGES/vlc.mo
@@ -214,3 +228,4 @@
%%NLS%%share/locale/zh_CN/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/zh_TW/LC_MESSAGES/vlc.mo
%%NLS%%share/locale/zu/LC_MESSAGES/vlc.mo
+share/metainfo/vlc.appdata.xml
File Metadata
Details
Attached
Mime Type
text/plain
Expires
Fri, Feb 28, 11:25 AM (18 h, 51 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
16884827
Default Alt Text
D14842.id48373.diff (49 KB)
Attached To
Mode
D14842: Update multimedia/vlc to upstream version 3.0.4
Attached
Detach File
Event Timeline
Log In to Comment
Index: multimedia/vlc/files/patch-src-network-udp.c
===================================================================
--- multimedia/vlc/files/patch-src-network-udp.c
+++ multimedia/vlc/files/patch-src-network-udp.c
@@ -1,11 +1,11 @@
---- src/network/udp.c.orig
+--- src/network/udp.c.orig 2018-01-17 13:29:46 UTC
+++ src/network/udp.c
-@@ -383,7 +383,7 @@ int net_Subscribe (vlc_object_t *obj, in
+@@ -315,7 +315,7 @@ net_SourceSubscribe (vlc_object_t *obj,
{
- /* MCAST_JOIN_GROUP was introduced to OS X in v10.7, but it doesn't work,
- * so ignore it to use the same code as on 10.5 or 10.6 */
--#if defined (MCAST_JOIN_GROUP) && !defined (__APPLE__)
-+#if defined (MCAST_JOIN_GROUP) && !defined (__APPLE__) && !defined (__FreeBSD__)
- /* Agnostic SSM multicast join */
+ /* MCAST_JOIN_SOURCE_GROUP was introduced to OS X in v10.7, but it doesn't work,
+ * so ignore it to use the same code path as on 10.5 or 10.6 */
+-#if defined (MCAST_JOIN_SOURCE_GROUP) && !defined (__APPLE__)
++#if defined (MCAST_JOIN_SOURCE_GROUP) && !defined (__APPLE__) && !defined (__FreeBSD__)
+ /* Family-agnostic Source-Specific Multicast join */
int level;
- struct group_req gr;
+ struct group_source_req gsr;